You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2013/04/17 19:38:18 UTC

svn commit: r1469004 [6/11] - in /commons/proper/collections/trunk: ./ src/main/java/org/apache/commons/collections/ src/main/java/org/apache/commons/collections/bag/ src/main/java/org/apache/commons/collections/bidimap/ src/main/java/org/apache/common...

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/ReferenceMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/ReferenceMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/ReferenceMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/ReferenceMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -41,7 +41,7 @@ import java.io.Serializable;
  * hard keys and soft values, providing a memory-sensitive cache.
  * <p>
  * This map is similar to
- * {@link org.apache.commons.collections.map.ReferenceIdentityMap ReferenceIdentityMap}.
+ * {@link org.apache.commons.collections4.map.ReferenceIdentityMap ReferenceIdentityMap}.
  * It differs in that keys and values in this class are compared using <code>equals()</code>.
  * <p>
  * This {@link java.util.Map Map} implementation does <i>not</i> allow null elements.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/SingletonMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/SingletonMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/SingletonMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/SingletonMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
 import java.io.Serializable;
 import java.util.AbstractSet;
@@ -25,13 +25,13 @@ import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Set;
 
-import org.apache.commons.collections.BoundedMap;
-import org.apache.commons.collections.KeyValue;
-import org.apache.commons.collections.OrderedMap;
-import org.apache.commons.collections.OrderedMapIterator;
-import org.apache.commons.collections.ResettableIterator;
-import org.apache.commons.collections.iterators.SingletonIterator;
-import org.apache.commons.collections.keyvalue.TiedMapEntry;
+import org.apache.commons.collections4.BoundedMap;
+import org.apache.commons.collections4.KeyValue;
+import org.apache.commons.collections4.OrderedMap;
+import org.apache.commons.collections4.OrderedMapIterator;
+import org.apache.commons.collections4.ResettableIterator;
+import org.apache.commons.collections4.iterators.SingletonIterator;
+import org.apache.commons.collections4.keyvalue.TiedMapEntry;
 
 /**
  * A <code>Map</code> implementation that holds a single item and is fixed size.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/StaticBucketMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/StaticBucketMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/StaticBucketMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/StaticBucketMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
 import java.util.AbstractCollection;
 import java.util.AbstractSet;
@@ -25,7 +25,7 @@ import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Set;
 
-import org.apache.commons.collections.KeyValue;
+import org.apache.commons.collections4.KeyValue;
 
 /**
  * A StaticBucketMap is an efficient, thread-safe implementation of

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/TransformedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/TransformedMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/TransformedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/TransformedMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -22,7 +22,7 @@ import java.io.ObjectOutputStream;
 import java.io.Serializable;
 import java.util.Map;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Decorates another <code>Map</code> to transform objects that are added.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/TransformedSortedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/TransformedSortedMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/TransformedSortedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/TransformedSortedMap.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
 import java.util.Comparator;
 import java.util.Map;
 import java.util.SortedMap;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Decorates another <code>SortedMap </code> to transform objects that are added.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableEntrySet.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableEntrySet.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableEntrySet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableEntrySet.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
 import java.lang.reflect.Array;
 import java.util.Collection;
@@ -22,10 +22,10 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.iterators.AbstractIteratorDecorator;
-import org.apache.commons.collections.keyvalue.AbstractMapEntryDecorator;
-import org.apache.commons.collections.set.AbstractSetDecorator;
+import org.apache.commons.collections4.set.AbstractSetDecorator;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.iterators.AbstractIteratorDecorator;
+import org.apache.commons.collections4.keyvalue.AbstractMapEntryDecorator;
 
 /**
  * Decorates a map entry <code>Set</code> to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -24,13 +24,13 @@ import java.util.Collection;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.collections.IterableMap;
-import org.apache.commons.collections.MapIterator;
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.collection.UnmodifiableCollection;
-import org.apache.commons.collections.iterators.EntrySetMapIterator;
-import org.apache.commons.collections.iterators.UnmodifiableMapIterator;
-import org.apache.commons.collections.set.UnmodifiableSet;
+import org.apache.commons.collections4.set.UnmodifiableSet;
+import org.apache.commons.collections4.IterableMap;
+import org.apache.commons.collections4.MapIterator;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.collection.UnmodifiableCollection;
+import org.apache.commons.collections4.iterators.EntrySetMapIterator;
+import org.apache.commons.collections4.iterators.UnmodifiableMapIterator;
 
 /**
  * Decorates another <code>Map</code> to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableOrderedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableOrderedMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableOrderedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableOrderedMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -24,12 +24,12 @@ import java.util.Collection;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.collections.OrderedMap;
-import org.apache.commons.collections.OrderedMapIterator;
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.collection.UnmodifiableCollection;
-import org.apache.commons.collections.iterators.UnmodifiableOrderedMapIterator;
-import org.apache.commons.collections.set.UnmodifiableSet;
+import org.apache.commons.collections4.set.UnmodifiableSet;
+import org.apache.commons.collections4.OrderedMap;
+import org.apache.commons.collections4.OrderedMapIterator;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.collection.UnmodifiableCollection;
+import org.apache.commons.collections4.iterators.UnmodifiableOrderedMapIterator;
 
 /**
  * Decorates another <code>OrderedMap</code> to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableSortedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableSortedMap.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableSortedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/UnmodifiableSortedMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -26,9 +26,9 @@ import java.util.Map;
 import java.util.Set;
 import java.util.SortedMap;
 
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.collection.UnmodifiableCollection;
-import org.apache.commons.collections.set.UnmodifiableSet;
+import org.apache.commons.collections4.set.UnmodifiableSet;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.collection.UnmodifiableCollection;
 
 /**
  * Decorates another <code>SortedMap</code> to ensure it can't be altered.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/package-info.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/package-info.java Wed Apr 17 17:37:03 2013
@@ -24,4 +24,4 @@
  *
  * @version $Id$
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/AbstractQueueDecorator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/AbstractQueueDecorator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/AbstractQueueDecorator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/AbstractQueueDecorator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/AbstractQueueDecorator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/AbstractQueueDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/AbstractQueueDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.queue;
+package org.apache.commons.collections4.queue;
 
 import java.util.Queue;
 
-import org.apache.commons.collections.collection.AbstractCollectionDecorator;
+import org.apache.commons.collections4.collection.AbstractCollectionDecorator;
 
 /**
  * Decorates another {@link Queue} to provide additional behaviour.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/CircularFifoQueue.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/CircularFifoQueue.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/CircularFifoQueue.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/CircularFifoQueue.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/CircularFifoQueue.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/CircularFifoQueue.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/CircularFifoQueue.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.queue;
+package org.apache.commons.collections4.queue;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -27,7 +27,7 @@ import java.util.Iterator;
 import java.util.NoSuchElementException;
 import java.util.Queue;
 
-import org.apache.commons.collections.BoundedCollection;
+import org.apache.commons.collections4.BoundedCollection;
 
 /**
  * CircularFifoQueue is a first-in first-out queue with a fixed size that

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/PredicatedQueue.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/PredicatedQueue.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/PredicatedQueue.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/PredicatedQueue.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/PredicatedQueue.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/PredicatedQueue.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/PredicatedQueue.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.queue;
+package org.apache.commons.collections4.queue;
 
 import java.util.Queue;
 
-import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.collection.PredicatedCollection;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.collection.PredicatedCollection;
 
 /**
  * Decorates another {@link Queue} to validate that additions

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/TransformedQueue.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/TransformedQueue.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/TransformedQueue.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/TransformedQueue.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/TransformedQueue.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/TransformedQueue.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/TransformedQueue.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.queue;
+package org.apache.commons.collections4.queue;
 
 import java.util.Queue;
 
-import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.collection.TransformedCollection;
+import org.apache.commons.collections4.Transformer;
+import org.apache.commons.collections4.collection.TransformedCollection;
 
 /**
  * Decorates another {@link Queue} to transform objects that are added.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/UnmodifiableQueue.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/UnmodifiableQueue.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/UnmodifiableQueue.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/UnmodifiableQueue.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/UnmodifiableQueue.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/UnmodifiableQueue.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/UnmodifiableQueue.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.queue;
+package org.apache.commons.collections4.queue;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -24,8 +24,8 @@ import java.util.Collection;
 import java.util.Iterator;
 import java.util.Queue;
 
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.iterators.UnmodifiableIterator;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.iterators.UnmodifiableIterator;
 
 /**
  * Decorates another {@link Queue} to ensure it can't be altered.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/package-info.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/package-info.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/package-info.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/package-info.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/package-info.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/queue/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/queue/package-info.java Wed Apr 17 17:37:03 2013
@@ -31,4 +31,4 @@
  * 
  * @version $Id$
  */
-package org.apache.commons.collections.queue;
+package org.apache.commons.collections4.queue;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSerializableSetDecorator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/AbstractSerializableSetDecorator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSerializableSetDecorator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSerializableSetDecorator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/AbstractSerializableSetDecorator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/AbstractSerializableSetDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSerializableSetDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSetDecorator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/AbstractSetDecorator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSetDecorator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSetDecorator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/AbstractSetDecorator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/AbstractSetDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSetDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.util.Set;
 
-import org.apache.commons.collections.collection.AbstractCollectionDecorator;
+import org.apache.commons.collections4.collection.AbstractCollectionDecorator;
 
 /**
  * Decorates another <code>Set</code> to provide additional behaviour.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSortedSetDecorator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/AbstractSortedSetDecorator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSortedSetDecorator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSortedSetDecorator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/AbstractSortedSetDecorator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/AbstractSortedSetDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/AbstractSortedSetDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.util.Comparator;
 import java.util.Set;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/CompositeSet.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/CompositeSet.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/CompositeSet.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/CompositeSet.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/CompositeSet.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/CompositeSet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/CompositeSet.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.io.Serializable;
 import java.lang.reflect.Array;
@@ -26,10 +26,10 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
-import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.collections.iterators.EmptyIterator;
-import org.apache.commons.collections.iterators.IteratorChain;
-import org.apache.commons.collections.list.UnmodifiableList;
+import org.apache.commons.collections4.CollectionUtils;
+import org.apache.commons.collections4.iterators.EmptyIterator;
+import org.apache.commons.collections4.iterators.IteratorChain;
+import org.apache.commons.collections4.list.UnmodifiableList;
 
 /**
  * Decorates a set of other sets to provide a single unified view.
@@ -39,7 +39,7 @@ import org.apache.commons.collections.li
  * If no strategy is provided then add is unsupported.
  * <p>
  * From version 4.0, this class does not extend
- * {@link org.apache.commons.collections.collection.CompositeCollection CompositeCollection}
+ * {@link org.apache.commons.collections4.collection.CompositeCollection CompositeCollection}
  * anymore due to its input restrictions (only accepts Sets).
  * See <a href="https://issues.apache.org/jira/browse/COLLECTIONS-424">COLLECTIONS-424</a>
  * for more details.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/ListOrderedSet.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/ListOrderedSet.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/ListOrderedSet.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/ListOrderedSet.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/ListOrderedSet.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/ListOrderedSet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/ListOrderedSet.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -24,9 +24,9 @@ import java.util.List;
 import java.util.ListIterator;
 import java.util.Set;
 
-import org.apache.commons.collections.OrderedIterator;
-import org.apache.commons.collections.iterators.AbstractIteratorDecorator;
-import org.apache.commons.collections.list.UnmodifiableList;
+import org.apache.commons.collections4.OrderedIterator;
+import org.apache.commons.collections4.iterators.AbstractIteratorDecorator;
+import org.apache.commons.collections4.list.UnmodifiableList;
 
 /**
  * Decorates another <code>Set</code> to ensure that the order of addition is

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/MapBackedSet.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/MapBackedSet.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/MapBackedSet.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/MapBackedSet.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/MapBackedSet.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/MapBackedSet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/MapBackedSet.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.io.Serializable;
 import java.util.Collection;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/PredicatedSet.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/PredicatedSet.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/PredicatedSet.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/PredicatedSet.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/PredicatedSet.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/PredicatedSet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/PredicatedSet.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.util.Set;
 
-import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.collection.PredicatedCollection;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.collection.PredicatedCollection;
 
 /**
  * Decorates another <code>Set</code> to validate that all additions

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/PredicatedSortedSet.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/PredicatedSortedSet.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/PredicatedSortedSet.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/PredicatedSortedSet.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/PredicatedSortedSet.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/PredicatedSortedSet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/PredicatedSortedSet.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.util.Comparator;
 import java.util.SortedSet;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Decorates another <code>SortedSet</code> to validate that all additions

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/TransformedSet.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/TransformedSet.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/TransformedSet.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/TransformedSet.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/TransformedSet.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/TransformedSet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/TransformedSet.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.util.Set;
 
-import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.collection.TransformedCollection;
+import org.apache.commons.collections4.Transformer;
+import org.apache.commons.collections4.collection.TransformedCollection;
 
 /**
  * Decorates another <code>Set</code> to transform objects that are added.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/TransformedSortedSet.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/TransformedSortedSet.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/TransformedSortedSet.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/TransformedSortedSet.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/TransformedSortedSet.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/TransformedSortedSet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/TransformedSortedSet.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.util.Comparator;
 import java.util.SortedSet;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Decorates another <code>SortedSet</code> to transform objects that are added.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/UnmodifiableSet.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/UnmodifiableSet.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/UnmodifiableSet.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/UnmodifiableSet.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/UnmodifiableSet.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/UnmodifiableSet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/UnmodifiableSet.java Wed Apr 17 17:37:03 2013
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.Set;
 
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.iterators.UnmodifiableIterator;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.iterators.UnmodifiableIterator;
 
 /**
  * Decorates another <code>Set</code> to ensure it can't be altered.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/UnmodifiableSortedSet.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/UnmodifiableSortedSet.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/UnmodifiableSortedSet.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/UnmodifiableSortedSet.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/UnmodifiableSortedSet.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/UnmodifiableSortedSet.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/UnmodifiableSortedSet.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -24,8 +24,8 @@ import java.util.Collection;
 import java.util.Iterator;
 import java.util.SortedSet;
 
-import org.apache.commons.collections.Unmodifiable;
-import org.apache.commons.collections.iterators.UnmodifiableIterator;
+import org.apache.commons.collections4.Unmodifiable;
+import org.apache.commons.collections4.iterators.UnmodifiableIterator;
 
 /**
  * Decorates another <code>SortedSet</code> to ensure it can't be altered.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/package-info.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/package-info.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/package-info.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/package-info.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/package-info.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/set/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/set/package-info.java Wed Apr 17 17:37:03 2013
@@ -37,4 +37,4 @@
  *
  * @version $Id$
  */
-package org.apache.commons.collections.set;
+package org.apache.commons.collections4.set;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/AbstractIterableGetMapDecorator.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/splitmap/AbstractIterableGetMapDecorator.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/AbstractIterableGetMapDecorator.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/AbstractIterableGetMapDecorator.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/splitmap/AbstractIterableGetMapDecorator.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/splitmap/AbstractIterableGetMapDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/AbstractIterableGetMapDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.splitmap;
+package org.apache.commons.collections4.splitmap;
 
 import java.util.Collection;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.collections.IterableGet;
-import org.apache.commons.collections.MapIterator;
-import org.apache.commons.collections.map.EntrySetToMapIteratorAdapter;
+import org.apache.commons.collections4.IterableGet;
+import org.apache.commons.collections4.MapIterator;
+import org.apache.commons.collections4.map.EntrySetToMapIteratorAdapter;
 
 /**
  * {@link IterableGet} that uses a {@link Map}<K, V> for the
- * {@link org.apache.commons.collections.Get Get}<K, V> implementation.
+ * {@link org.apache.commons.collections4.Get Get}<K, V> implementation.
  *
  * @since 4.0
  * @version $Id$

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/TransformedMap.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/splitmap/TransformedMap.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/TransformedMap.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/TransformedMap.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/splitmap/TransformedMap.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/splitmap/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/package-info.java Wed Apr 17 17:37:03 2013
@@ -16,8 +16,8 @@
  */
 /**
  * The "split map" concept is that of an object that implements
- * the {@link org.apache.commons.collections.Put Put} and
- * {@link org.apache.commons.collections.Get Get} interfaces,
+ * the {@link org.apache.commons.collections4.Put Put} and
+ * {@link org.apache.commons.collections4.Get Get} interfaces,
  * with <i>differing</i> generic types. This is like a pre-generics
  * {@link java.util.Map Map} whose input key/value constraints are
  * different than its output key/value constraints.  While it would
@@ -25,8 +25,8 @@
  * key/value constraints, this would be a {@link java.util.Map Map}
  * and would therefore make little sense (any Commons Collections
  * {@link java.util.Map Map} implementation will also implement
- * {@link org.apache.commons.collections.Put Put} and
- * {@link org.apache.commons.collections.Get Get} with matching
+ * {@link org.apache.commons.collections4.Put Put} and
+ * {@link org.apache.commons.collections4.Get Get} with matching
  * generic parameters).
  * <p>
  * The following decorators are provided:
@@ -36,4 +36,4 @@
  *
  * @version $Id$
  */
-package org.apache.commons.collections.splitmap;
+package org.apache.commons.collections4.splitmap;

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/AbstractKeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/AbstractKeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/AbstractKeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/AbstractKeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/AbstractKeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/AbstractKeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/AbstractKeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 /**
  * TODO: add javadoc

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/AbstractTrie.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/AbstractTrie.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/AbstractTrie.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/AbstractTrie.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/AbstractTrie.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/AbstractTrie.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/AbstractTrie.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 import java.io.Serializable;
 import java.util.AbstractMap;
 import java.util.Map;
 
-import org.apache.commons.collections.Trie;
+import org.apache.commons.collections4.Trie;
 
 /**
  * This class provides some basic {@link Trie} functionality and 

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ByteArrayKeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/ByteArrayKeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ByteArrayKeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ByteArrayKeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/ByteArrayKeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/ByteArrayKeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ByteArrayKeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 /**
  * A {@link KeyAnalyzer} for byte[]s.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ByteKeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/ByteKeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ByteKeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ByteKeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/ByteKeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/ByteKeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ByteKeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 /**
  * A {@link KeyAnalyzer} for {@link Byte}s.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/CharArrayKeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/CharArrayKeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/CharArrayKeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/CharArrayKeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/CharArrayKeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/CharArrayKeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/CharArrayKeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 /**
  * An {@link KeyAnalyzer} for {@code char[]}s.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/CharacterKeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/CharacterKeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/CharacterKeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/CharacterKeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/CharacterKeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/CharacterKeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/CharacterKeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 /**
  * A {@link KeyAnalyzer} for {@link Character}s.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/IntegerKeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/IntegerKeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/IntegerKeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/IntegerKeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/IntegerKeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/IntegerKeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/IntegerKeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 /**
  * A {@link KeyAnalyzer} for {@link Integer}s.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/KeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/KeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/KeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/KeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/KeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/LongKeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/LongKeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 /**
  * A {@link KeyAnalyzer} for {@link Long}s.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/PatriciaTrie.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/PatriciaTrie.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/PatriciaTrie.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/PatriciaTrie.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/PatriciaTrie.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/PatriciaTrie.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/PatriciaTrie.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 import java.util.AbstractMap;
 import java.util.AbstractSet;
@@ -26,7 +26,7 @@ import java.util.NoSuchElementException;
 import java.util.Set;
 import java.util.SortedMap;
 
-import org.apache.commons.collections.Trie;
+import org.apache.commons.collections4.Trie;
 
 /**
  * <h3>PATRICIA {@link Trie}</h3>

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/PatriciaTrieBase.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/PatriciaTrieBase.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/PatriciaTrieBase.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/PatriciaTrieBase.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/PatriciaTrieBase.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/ShortKeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ShortKeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 /**
  * A {@link KeyAnalyzer} for {@link Short}s.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/StringKeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/StringKeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/StringKeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/StringKeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/StringKeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/StringKeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/StringKeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 /**
  * An {@link KeyAnalyzer} for {@link String}s.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/SynchronizedTrie.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/SynchronizedTrie.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/SynchronizedTrie.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/SynchronizedTrie.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/SynchronizedTrie.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/SynchronizedTrie.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/SynchronizedTrie.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 import java.io.Serializable;
 import java.util.Collection;
@@ -24,8 +24,8 @@ import java.util.Map;
 import java.util.Set;
 import java.util.SortedMap;
 
-import org.apache.commons.collections.Trie;
-import org.apache.commons.collections.collection.SynchronizedCollection;
+import org.apache.commons.collections4.Trie;
+import org.apache.commons.collections4.collection.SynchronizedCollection;
 
 /**
  * A synchronized {@link Trie}.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/UnmodifiableTrie.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/UnmodifiableTrie.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/UnmodifiableTrie.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/UnmodifiableTrie.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/UnmodifiableTrie.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/UnmodifiableTrie.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/UnmodifiableTrie.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 import java.io.Serializable;
 import java.util.Collection;
@@ -24,8 +24,8 @@ import java.util.Map;
 import java.util.Set;
 import java.util.SortedMap;
 
-import org.apache.commons.collections.Trie;
-import org.apache.commons.collections.Unmodifiable;
+import org.apache.commons.collections4.Trie;
+import org.apache.commons.collections4.Unmodifiable;
 
 /**
  * An unmodifiable {@link Trie}.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/package-info.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/package-info.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/package-info.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/package-info.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/package-info.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/package-info.java Wed Apr 17 17:37:03 2013
@@ -16,7 +16,7 @@
  */
 /**
  * This package contains implementations of the
- * {@link org.apache.commons.collections.Trie Trie} interface.
+ * {@link org.apache.commons.collections4.Trie Trie} interface.
  * <p>
  * The implementations are in the form of direct implementations and decorators.
  * A decorator wraps another implementation of the interface to add some
@@ -35,4 +35,4 @@
  *
  * @version $Id$
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractArrayListTest.java (from r1468597, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractArrayListTest.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractArrayListTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractArrayListTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractArrayListTest.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractArrayListTest.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractArrayListTest.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 import java.util.ArrayList;
 
-import org.apache.commons.collections.list.AbstractListTest;
+import org.apache.commons.collections4.list.AbstractListTest;
 
 /**
  * Abstract test class for ArrayList.

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractLinkedListTest.java (from r1468597, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractLinkedListTest.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractLinkedListTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractLinkedListTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractLinkedListTest.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractLinkedListTest.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractLinkedListTest.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 import java.util.Arrays;
 import java.util.Collection;
@@ -22,7 +22,7 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.NoSuchElementException;
 
-import org.apache.commons.collections.list.AbstractListTest;
+import org.apache.commons.collections4.list.AbstractListTest;
 
 /**
  * Tests base {@link java.util.LinkedList} methods and contracts.

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractObjectTest.java (from r1468597, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractObjectTest.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractObjectTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractObjectTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractObjectTest.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractObjectTest.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractObjectTest.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -43,7 +43,7 @@ import java.io.Serializable;
 public abstract class AbstractObjectTest extends BulkTest {
 
     /** Current major release for Collections */
-    public static final int COLLECTIONS_MAJOR_VERSION = 3;
+    public static final int COLLECTIONS_MAJOR_VERSION = 4;
     
     /**
      * JUnit constructor.
@@ -209,9 +209,8 @@ public abstract class AbstractObjectTest
     //-----------------------------------------------------------------------
     /**
      * Get the version of Collections that this object tries to
-     * maintain serialization compatibility with. Defaults to 1, the
-     * earliest Collections version. (Note: some collections did not
-     * even exist in this version).
+     * maintain serialization compatibility with. Defaults to 4, due to
+     * the package change to collections4 introduced in version 4.
      * 
      * This constant makes it possible for TestMap (and other subclasses,
      * if necessary) to automatically check SVN for a versionX copy of a
@@ -224,7 +223,7 @@ public abstract class AbstractObjectTest
      * tested for compatibility with previous versions.
      */
     public String getCompatibilityVersion() {
-        return "1";
+        return "4";
     }
 
     protected String getCanonicalEmptyCollectionName(final Object object) {

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractTreeMapTest.java (from r1468597, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractTreeMapTest.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractTreeMapTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractTreeMapTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractTreeMapTest.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/AbstractTreeMapTest.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/AbstractTreeMapTest.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 import java.util.TreeMap;
 
-import org.apache.commons.collections.map.AbstractMapTest;
+import org.apache.commons.collections4.map.AbstractMapTest;
 
 /**
  * Tests TreeMap.

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/ArrayStackTest.java (from r1468597, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/ArrayStackTest.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/ArrayStackTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/ArrayStackTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/ArrayStackTest.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/ArrayStackTest.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/ArrayStackTest.java Wed Apr 17 17:37:03 2013
@@ -14,10 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 import java.util.EmptyStackException;
 
+import org.apache.commons.collections4.ArrayStack;
+
 import junit.framework.Test;
 
 /**
@@ -107,5 +109,17 @@ public class ArrayStackTest<E> extends A
                      -1, stack.search("Missing Item"));
 
     }
+    
+    @Override
+    public String getCompatibilityVersion() {
+        return "4";
+    }
+
+//    public void testCreate() throws Exception {
+//        resetEmpty();
+//        writeExternalFormToDisk((java.io.Serializable) getCollection(), "src/test/resources/data/test/ArrayStack.emptyCollection.version4.obj");
+//        resetFull();
+//        writeExternalFormToDisk((java.io.Serializable) getCollection(), "src/test/resources/data/test/ArrayStack.fullCollection.version4.obj");
+//    }
 
 }

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/BagUtilsTest.java (from r1468597, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/BagUtilsTest.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/BagUtilsTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/BagUtilsTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/BagUtilsTest.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/BagUtilsTest.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/BagUtilsTest.java Wed Apr 17 17:37:03 2013
@@ -14,21 +14,26 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 import junit.framework.Test;
 
-import org.apache.commons.collections.bag.HashBag;
-import org.apache.commons.collections.bag.PredicatedBag;
-import org.apache.commons.collections.bag.PredicatedSortedBag;
-import org.apache.commons.collections.bag.SynchronizedBag;
-import org.apache.commons.collections.bag.SynchronizedSortedBag;
-import org.apache.commons.collections.bag.TransformedBag;
-import org.apache.commons.collections.bag.TransformedSortedBag;
-import org.apache.commons.collections.bag.TreeBag;
-import org.apache.commons.collections.bag.UnmodifiableBag;
-import org.apache.commons.collections.bag.UnmodifiableSortedBag;
-import org.apache.commons.collections.functors.TruePredicate;
+import org.apache.commons.collections4.Bag;
+import org.apache.commons.collections4.BagUtils;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.Transformer;
+import org.apache.commons.collections4.TransformerUtils;
+import org.apache.commons.collections4.bag.HashBag;
+import org.apache.commons.collections4.bag.PredicatedBag;
+import org.apache.commons.collections4.bag.PredicatedSortedBag;
+import org.apache.commons.collections4.bag.SynchronizedBag;
+import org.apache.commons.collections4.bag.SynchronizedSortedBag;
+import org.apache.commons.collections4.bag.TransformedBag;
+import org.apache.commons.collections4.bag.TransformedSortedBag;
+import org.apache.commons.collections4.bag.TreeBag;
+import org.apache.commons.collections4.bag.UnmodifiableBag;
+import org.apache.commons.collections4.bag.UnmodifiableSortedBag;
+import org.apache.commons.collections4.functors.TruePredicate;
 
 /**
  * Tests for BagUtils factory methods.

Copied: commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/BulkTest.java (from r1468597, commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/BulkTest.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/BulkTest.java?p2=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/BulkTest.java&p1=commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/BulkTest.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/test/java/org/apache/commons/collections/BulkTest.java (original)
+++ commons/proper/collections/trunk/src/test/java/org/apache/commons/collections4/BulkTest.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections;
+package org.apache.commons.collections4;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/package-info.java Wed Apr 17 17:37:03 2013
@@ -16,8 +16,8 @@
  */
 /**
  * This package contains implementations of the {@link java.util.Map Map},
  * {@link org.apache.commons.collections.IterableMap IterableMap},
  * {@link org.apache.commons.collections.OrderedMap OrderedMap} and
  * {@link java.util.SortedMap SortedMap} interfaces.
  * A Map provides a lookup from a key to a value.
  * A number of implementations also support the new MapIterator interface that enables
@@ -51,5 +51,5 @@
  *
  * @version $Id$
  */
-package org.apache.commons.collections.map;
+package org.apache.commons.collections4.map;
 
@@ -16,8 +16,8 @@
 /**
  * This package contains implementations of the {@link java.util.Map Map},
- * {@link org.apache.commons.collections.IterableMap IterableMap},
- * {@link org.apache.commons.collections.OrderedMap OrderedMap} and
+ * {@link org.apache.commons.collections4.IterableMap IterableMap},
+ * {@link org.apache.commons.collections4.OrderedMap OrderedMap} and
  * {@link java.util.SortedMap SortedMap} interfaces.
  * A Map provides a lookup from a key to a value.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/package-info.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/package-info.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/package-info.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/package-info.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/package-info.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/splitmap/TransformedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/TransformedMap.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.splitmap;
+package org.apache.commons.collections4.splitmap;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -22,9 +22,9 @@ import java.io.ObjectOutputStream;
 import java.io.Serializable;
 import java.util.Map;
 
-import org.apache.commons.collections.Put;
-import org.apache.commons.collections.Transformer;
-import org.apache.commons.collections.map.LinkedMap;
+import org.apache.commons.collections4.Put;
+import org.apache.commons.collections4.Transformer;
+import org.apache.commons.collections4.map.LinkedMap;
 
 /**
  * Decorates another {@link Map} to transform objects that are added.
@@ -42,7 +42,7 @@ import org.apache.commons.collections.ma
  * synchronization.
  * <p>
  * The "put" and "get" type constraints of this class are mutually independent;
  * contrast with {@link org.apache.commons.collections.map.TransformedMap} which,
  * by virtue of its implementing {@link Map}&lt;K, V&gt;, must be constructed in such
  * a way that its read and write parameters are generalized to a common (super-)type.
  * In practice this would often mean <code>&gt;Object, Object&gt;</code>, defeating
@@ -50,13 +50,13 @@ import org.apache.commons.collections.ma
  * <p>
  * On the downside, this class is not drop-in compatible with {@link java.util.Map}
  * but is intended to be worked with either directly or by {@link Put} and
- * {@link org.apache.commons.collections.Get Get} generalizations.
+ * {@link org.apache.commons.collections4.Get Get} generalizations.
  *
  * @since 4.0
  * @version $Id$
  *
- * @see org.apache.commons.collections.SplitMapUtils#readableMap(Get)
- * @see org.apache.commons.collections.SplitMapUtils#writableMap(Put)
+ * @see org.apache.commons.collections4.SplitMapUtils#readableMap(Get)
+ * @see org.apache.commons.collections4.SplitMapUtils#writableMap(Put)
  */
 public class TransformedMap<J, K, U, V> extends AbstractIterableGetMapDecorator<K, V>
         implements Put<J, U>, Serializable {
@@ -42,7 +42,7 @@ import org.apache.commons.collections.ma
  * <p>
  * The "put" and "get" type constraints of this class are mutually independent;
- * contrast with {@link org.apache.commons.collections.map.TransformedMap} which,
+ * contrast with {@link org.apache.commons.collections4.map.TransformedMap} which,
  * by virtue of its implementing {@link Map}&lt;K, V&gt;, must be constructed in such
  * a way that its read and write parameters are generalized to a common (super-)type.

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/package-info.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/splitmap/package-info.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/package-info.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/splitmap/package-info.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/splitmap/package-info.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/KeyAnalyzer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/KeyAnalyzer.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 import java.io.Serializable;
 import java.util.Comparator;
 
 /** 
  * Defines the interface to analyze {@link org.apache.commons.collections.Trie Trie} keys on a bit level. 
  * {@link KeyAnalyzer}'s methods return the length of the key in bits, 
  * whether or not a bit is set, and bits per element in the key. 
  * <p>
@@ -14,13 +14,13 @@
 
 /** 
- * Defines the interface to analyze {@link org.apache.commons.collections.Trie Trie} keys on a bit level. 
+ * Defines the interface to analyze {@link org.apache.commons.collections4.Trie Trie} keys on a bit level. 
  * {@link KeyAnalyzer}'s methods return the length of the key in bits, 
  * whether or not a bit is set, and bits per element in the key. 

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/LongKeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/LongKeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/LongKeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/LongKeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/LongKeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/PatriciaTrieBase.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/PatriciaTrieBase.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.trie;
+package org.apache.commons.collections4.trie;
 
 import java.util.AbstractCollection;
 import java.util.AbstractSet;
@@ -25,7 +25,7 @@ import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Set;
 
-import org.apache.commons.collections.Trie.Cursor.Decision;
+import org.apache.commons.collections4.Trie.Cursor.Decision;
 
 /**
  * This class implements the base PATRICIA algorithm and everything that
@@ -69,8 +69,8 @@ abstract class PatriciaTrieBase<K, V> ex
     }
     
     /**
      * Constructs a new {@link org.apache.commons.collections.Trie Trie} using the given {@link KeyAnalyzer} 
      * and initializes the {@link org.apache.commons.collections.Trie Trie} with the values from the 
      * provided {@link Map}.
      */
     public PatriciaTrieBase(final KeyAnalyzer<? super K> keyAnalyzer, 
@@ -69,8 +69,8 @@ abstract class PatriciaTrieBase<K, V> ex
     
     /**
-     * Constructs a new {@link org.apache.commons.collections.Trie Trie} using the given {@link KeyAnalyzer} 
-     * and initializes the {@link org.apache.commons.collections.Trie Trie} with the values from the 
+     * Constructs a new {@link org.apache.commons.collections4.Trie Trie} using the given {@link KeyAnalyzer} 
+     * and initializes the {@link org.apache.commons.collections4.Trie Trie} with the values from the 
      * provided {@link Map}.
      */

Copied: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ShortKeyAnalyzer.java (from r1468597, commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/ShortKeyAnalyzer.java)
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ShortKeyAnalyzer.java?p2=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/trie/ShortKeyAnalyzer.java&p1=commons/proper/collections/trunk/src/main/java/org/apache/commons/collections/trie/ShortKeyAnalyzer.java&r1=1468597&r2=1469004&rev=1469004&view=diff
==============================================================================